agents property
Map of all available agents, indexed by their VanturaAgent.name.
Implementation
final Map<String, VanturaAgent> agents = {};
Map of all available agents, indexed by their VanturaAgent.name.
final Map<String, VanturaAgent> agents = {};