ApiTestArgs class

Arguments for the ApiTestTool.

Constructors

ApiTestArgs({required String url, String? method})
Creates a new instance of ApiTestArgs.
ApiTestArgs.fromJson(Map<String, dynamic> json)
Creates ApiTestArgs from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
method String?
The HTTP method to use (e.g., 'GET', 'POST'). Defaults to 'GET'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
The absolute URL of the API endpoint to test.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited