CancellationToken class

A token that can be passed to operations to allow them to be cancelled.

Constructors

CancellationToken()

Properties

hashCode int
The hash code for this object.
no setterinherited
isCancelled bool
Whether the cancellation has been requested.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
Cancels the operation associated with this token.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited