VanturaSecurity class

A utility for redacting sensitive information (PII) from prompts and logs.

Constructors

VanturaSecurity()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

creditCardRegex RegExp
final
emailRegex RegExp
Regular expressions for common PII patterns.
final
phoneRegex RegExp
final
ssnRegex RegExp
final

Static Methods

redact(String text) String
Redacts PII from a given string.