VanturaMemory class

Constructors

VanturaMemory(VanturaLogger logger, VanturaClient client, {int shortLimit = 10, int longLimit = 5, VanturaPersistence? persistence})
Creates an VanturaMemory with the specified logger and client.

Properties

client VanturaClient
Client for AI communication, used for summarization.
final
hashCode int
The hash code for this object.
no setterinherited
logger VanturaLogger
Logger instance for logging operations.
final
longLimit int
final
persistence VanturaPersistence?
Persistence provider for conversation history.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortLimit int
final

Methods

addMessage(String role, String content, {List<Map<String, dynamic>>? toolCalls, String? toolCallId}) Future<void>
clear() → void
getMessages() List<Map<String, dynamic>>
init() Future<void>
Initializes memory by loading history from persistence.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited