MessageRole enum
Defines the role of a message in the conversation history.
Values
- system → const MessageRole
-
System instructions defining the agent's persona and rules.
- user → const MessageRole
-
Message from the human user.
- assistant → const MessageRole
-
Message from the AI assistant (may contain text or tool calls).
- tool → const MessageRole
-
Output from a tool execution.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MessageRole> - A constant List of the values in this enum, in order of their declaration.