core/vantura_observer library

Classes

SdkLoggerObserver
A default observer that redirects hooks to the internal VanturaLogger.
VanturaObserver
An observer that can hook into the reasoning cycle of a VanturaAgent.