SdkLoggerObserver class

A default observer that redirects hooks to the internal VanturaLogger.

Inheritance

Constructors

SdkLoggerObserver(dynamic logger)

Properties

hashCode int
The hash code for this object.
no setterinherited
logger → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(Object error, StackTrace stackTrace) → void
Called when the agent encounters an error.
override
onLlmRequest(List<VanturaMessage> messages) → void
Called before sending a request to the LLM.
inherited
onLlmResponse(VanturaResponse response) → void
Called after receiving a response from the LLM.
inherited
onRunFinish(VanturaResponse response) → void
Called when the agent completes a run.
override
onRunStart(String prompt, Map<String, dynamic>? config) → void
Called when the agent starts a new run.
override
onStepFinish(int stepNumber) → void
Called at the finish of a ReAct reasoning step.
inherited
onStepStart(int stepNumber) → void
Called at the start of a ReAct reasoning step.
inherited
onToolFinish(String toolName, String result) → void
Called after a tool execution completes.
override
onToolStart(String toolName, Map<String, dynamic> args) → void
Called before executing a tool.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited