VanturaState class

Manages the state of an VanturaAgent run for UI synchronization.

Uses ChangeNotifier to notify listeners of state changes during the agent's reasoning loop, enabling real-time UI updates.

Inheritance

Constructors

VanturaState()

Properties

currentStep String
Current step in the agent's reasoning loop.
getter/setter pair
errorMessage String?
Any error message, if the run failed.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isRunning bool
Whether the agent is currently running.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
completeRun() → void
Mark the run as completed successfully.
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
failRun(String error) → void
Mark the run as failed with an error.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reset() → void
Reset the state to idle.
startRun() → void
Start a new agent run.
toString() String
A string representation of this object.
inherited
updateStep(String step) → void
Update the current step.

Operators

operator ==(Object other) bool
The equality operator.
inherited