timeout property
Duration
get
timeout
Maximum time this tool is allowed to run before being cancelled. Defaults to 30 seconds.
Implementation
Duration get timeout => const Duration(seconds: 30);
Maximum time this tool is allowed to run before being cancelled. Defaults to 30 seconds.
Duration get timeout => const Duration(seconds: 30);