core/vantura_worker library

Classes

ErrorEvent
FinishEvent
LogEvent
RunCommand
StatusEvent
ThoughtEvent
ToolRequestEvent
ToolResponseCommand
VanturaWorker
A worker that manages an isolate for background agent execution.
VanturaWorkerEvent
Base class for all events sent from the VanturaWorker isolate to the main thread.
WorkerCommand
Commands sent from the main thread to the VanturaWorker isolate.