RunCommand class

Inheritance

Constructors

RunCommand({String? prompt, required String instructions, required List<Map<String, dynamic>> messages, required Map<String, dynamic> clientConfig, required List<Map<String, dynamic>> toolsConfig, bool redactPii = false})

Properties

clientConfig → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
instructions → String
final
messages → List<Map<String, dynamic>>
final
prompt → String?
final
redactPii → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolsConfig → List<Map<String, dynamic>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited