ToolRequestEvent class

Inheritance

Constructors

ToolRequestEvent({required String callId, required String toolName, required Map<String, dynamic> args})

Properties

args → Map<String, dynamic>
final
callId → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
finalinherited
toolName → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited