SimpleVanturaLogger class
Simple logger implementation for the Vantura SDK.
- Implemented types
Constructors
- SimpleVanturaLogger({VanturaLoggerOptions options = const VanturaLoggerOptions()})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → VanturaLoggerOptions
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
debug(
String message, {String? tag, Map< String, dynamic> ? extra}) → void -
Log a debug message.
override
-
error(
String message, {String? tag, Map< String, dynamic> ? extra, Object? error, StackTrace? stackTrace}) → void -
Log an error message.
override
-
info(
String message, {String? tag, Map< String, dynamic> ? extra}) → void -
Log an info message.
override
-
logPerformance(
String operation, Duration duration, {Map< String, dynamic> ? context}) → void -
Log performance metrics.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
warning(
String message, {String? tag, Map< String, dynamic> ? extra, Object? error}) → void -
Log a warning message.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited