VanturaLogger class abstract
Abstract logger interface for the Vantura SDK.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → VanturaLoggerOptions
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
debug(
String message, {String? tag, Map< String, dynamic> ? extra}) → void - Log a debug message.
-
error(
String message, {String? tag, Map< String, dynamic> ? extra, Object? error, StackTrace? stackTrace}) → void - Log a critical error that might prevent further execution.
-
info(
String message, {String? tag, Map< String, dynamic> ? extra}) → void - Log an info message.
-
logPerformance(
String operation, Duration duration, {Map< String, dynamic> ? context}) → void - Records the duration and context of a specific operation for profiling.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
warning(
String message, {String? tag, Map< String, dynamic> ? extra, Object? error}) → void - Log a warning message for potentially recoverable issues.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited