logPerformance abstract method
Records the duration and context of a specific operation for profiling.
Implementation
void logPerformance(
String operation,
Duration duration, {
Map<String, dynamic>? context,
});
Records the duration and context of a specific operation for profiling.
void logPerformance(
String operation,
Duration duration, {
Map<String, dynamic>? context,
});