VanturaLoggerOptions class

Configuration for Vantura logging.

Constructors

VanturaLoggerOptions({bool logSensitiveContent = false, VanturaLogLevel logLevel = VanturaLogLevel.info, List<String> redactedKeys = const ['api_key', 'apiKey', 'authorization', 'token', 'password', 'secret']})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
logLevel VanturaLogLevel
Minimum level to log. Errors will always be logged unless level is 'none'.
final
logSensitiveContent bool
Whether to log the actual content of prompts and AI responses. Set to false to prevent logging PII in production.
final
redactedKeys List<String>
List of keys in 'extra' or 'context' maps that should be redacted.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited