logSensitiveContent property
Whether to log the actual content of prompts and AI responses. Set to false to prevent logging PII in production.
Implementation
final bool logSensitiveContent;
Whether to log the actual content of prompts and AI responses. Set to false to prevent logging PII in production.
final bool logSensitiveContent;