markdown/nodes library
Classes
- BlockNode
- Represents a block-level element like a paragraph or header.
- BoldInline
- Bold text containing other children inlines.
- CodeInline
- Inline code or a monospace snippet.
- HeaderBlock
- A header with a specific level (1-6) and text content.
- HorizontalRuleBlock
-
A horizontal rule
<hr>. - InlineNode
- Represents an inline-level element like bold text or a link.
- ItalicInline
- Italic text containing other children inlines.
- ListBlock
- A bulleted list containing multiple items.
- MarkdownNode
- Base class for all elements in the markdown abstract syntax tree.
- ParagraphBlock
- A paragraph containing a list of inlines.
- TextInline
- Plain text inside a paragraph or other inline container.