HeaderBlock class

A header with a specific level (1-6) and text content.

Inheritance

Constructors

HeaderBlock(int level, String text)

Properties

hashCode int
The hash code for this object.
no setterinherited
level int
The level of the header (e.g., 1 for #).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The raw text content of the header.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited