CalculatorArgs class
Arguments for the CalculatorTool.
Constructors
- CalculatorArgs({required String operation, required num a, required num b})
-
CalculatorArgs.fromJson(Map<
String, dynamic> json) -
Creates CalculatorArgs from a JSON map.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited