VanturaIterationException class
Thrown when the agent exceeds the maximum allowed reasoning iterations.
- Inheritance
-
- Object
- VanturaException
- VanturaIterationException
Constructors
- VanturaIterationException(int maxIterations)
-
Creates a VanturaIterationException with the specified
maxIterations.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxIterations → int
-
The maximum number of iterations that was exceeded.
final
- message → String
-
A human-readable message describing the error.
finalinherited
- originalError → Object?
-
The original error that caused this exception, if any.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited