VanturaRateLimitException class

Thrown when the agent hits an API rate limit (HTTP 429).

Inheritance

Constructors

VanturaRateLimitException(String message, {int? statusCode = 429, String? responseBody})
Creates a VanturaRateLimitException.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable message describing the error.
finalinherited
originalError Object?
The original error that caused this exception, if any.
finalinherited
responseBody String?
The raw response body from the API.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
The HTTP status code returned by the API.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited