VanturaToolException class
Thrown when a tool execution fails.
- Inheritance
-
- Object
- VanturaException
- VanturaToolException
Constructors
- VanturaToolException(String toolName, String message, {Object? originalError})
-
Creates a VanturaToolException for the specified
toolName.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A human-readable message describing the error.
finalinherited
- originalError → Object?
-
The original error that caused this exception, if any.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolName → String
-
The name of the tool that failed.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited