core/index library

Classes

AgentCoordinator
Coordinates multiple VanturaAgents, allowing them to hand off the conversation to each other based on user needs.
CancellationToken
A token that can be passed to operations to allow them to be cancelled.
NullArgs
Represents null arguments for tools that don't take any parameters.
SchemaHelper
Helper class for generating JSON schemas from Dart Maps. Simplifies tool parameter definition by automatically wrapping properties in the standard JSON schema object structure.
SimpleVanturaLogger
Simple logger implementation for the Vantura SDK.
TokenUsage
Tracks token usage out of a completed generation or run.
VanturaAgent
Agent that interacts with the Vantura API and uses tools.
VanturaClient
Client for interacting with the Vantura AI API.
VanturaLogger
Abstract logger interface for the Vantura SDK.
VanturaLoggerOptions
Configuration for Vantura logging.
VanturaMemory
VanturaPersistence
Interface for persistent storage of agent memory.
VanturaResponse
A response from the VanturaAgent.
VanturaState
Manages the state of an VanturaAgent run for UI synchronization.
VanturaTool<T>
Abstract base class for Vantura tools that can be used by the agent.

Enums

VanturaLogLevel
Log levels for Vantura SDK.

Properties

sdkLogger VanturaLogger
Global SDK logger instance. In a real app, developers should be able to replace this.
getter/setter pair