VanturaLogger class abstract

Abstract logger interface for the Vantura SDK.

Implementers

Constructors

VanturaLogger()

Properties

hashCode int
The hash code for this object.
no setterinherited
options VanturaLoggerOptions
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(String message, {String? tag, Map<String, dynamic>? extra}) → void
Log a debug message.
error(String message, {String? tag, Map<String, dynamic>? extra, Object? error, StackTrace? stackTrace}) → void
Log an error message.
info(String message, {String? tag, Map<String, dynamic>? extra}) → void
Log an info message.
logPerformance(String operation, Duration duration, {Map<String, dynamic>? context}) → void
Log performance metrics.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
warning(String message, {String? tag, Map<String, dynamic>? extra, Object? error}) → void
Log a warning message.

Operators

operator ==(Object other) bool
The equality operator.
inherited