CalculatorArgs class

Arguments for the CalculatorTool.

Constructors

CalculatorArgs({required String operation, required num a, required num b})
CalculatorArgs.fromJson(Map<String, dynamic> json)
Creates CalculatorArgs from a JSON map.
factory

Properties

a num
final
b num
final
hashCode int
The hash code for this object.
no setterinherited
operation String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited